@@ -191,15 +191,6 @@ char          xaccSplitGetReconcile (const Split *split);
 /** Set the date on which this split was reconciled by specifying the
  * time as time64. */
 void          xaccSplitSetDateReconciledSecs (Split *split, time64 time);
-/** Set the date on which this split was reconciled by specifying the
- * time as Timespec.  Caller still owns *ts! */
-void          xaccSplitSetDateReconciledTS (Split *split, Timespec *ts);
-/** Get the date on which this split was reconciled by having it
- * written into the Timespec that 'ts' is pointing to. */
-void          xaccSplitGetDateReconciledTS (const Split *split,
-        Timespec *ts);
-/** Returns the date (as Timespec) on which this split was reconciled. */
-Timespec      xaccSplitRetDateReconciledTS (const Split *split);
 
 /*################## Added for Reg2 #################*/
 /** Retrieve the date when the Split was reconciled. */
@@ -305,6 +296,15 @@ gnc_numeric xaccSplitGetBaseValue (const Split *split,
  */
 gnc_numeric xaccSplitGetBalance (const Split *split);
 
+/**
+ * The noclosing-balance is the currency-denominated balance of all
+ * transactions except 'closing' transactions. It is correctly
+ * adjusted for price fluctuations.
+ *
+ * Returns the running balance up to & including the indicated split.
+ */
+gnc_numeric xaccSplitGetNoclosingBalance (const Split *split);
+
 /**
  * The cleared-balance is the currency-denominated balance
  * of all transactions that have been marked as cleared or reconciled.
@@ -359,6 +359,7 @@ Split      * xaccSplitLookup (const GncGUID *guid, QofBook *book);
 
 /*################## Added for Reg2 #################*/
 /* Get a GList of unique transactions containing the given list of Splits. */
+GList *xaccSplitListGetUniqueTransactionsReversed (const GList *splits);
 GList *xaccSplitListGetUniqueTransactions(const GList *splits);
 /*################## Added for Reg2 #################*/
 /** Add a peer split to this split's lot-split list.
