@@ -50,9 +50,7 @@
 #ifndef GNC_GSETTINGS_H
 #define GNC_GSETTINGS_H
 
-#include <gio/gio.h>
-
-#define GSET_SCHEMA_PREFIX            "org.gnucash"
+#include <glib.h>
 
 /** Convert a partial schema name into a complete gsettings schema name.
  *
@@ -72,20 +70,23 @@
  */
 gchar *gnc_gsettings_normalize_schema_name (const gchar *name);
 
-
-/** Set the default gsettings schema prefix. This is
- *  used to generate complete schema id's if only
- *  partial id's are passed.
- */
-void gnc_gsettings_set_prefix (const gchar *prefix);
-
 /** Get the default gsettings schema prefix.
  *  If none was set explicitly, this defaults to
- *  "org.gnucash"
+ *  "org.gnucash.GnuCash"
  */
 const gchar *gnc_gsettings_get_prefix (void);
 
 
+/** Block all prefs callbacks, used while preference dialog is loaded.
+ */
+void gnc_gsettings_block_all (void);
+
+
+/** UnBlock all prefs callbacks, used while preference dialog is loaded.
+ */
+void gnc_gsettings_unblock_all (void);
+
+
 /** @name Listening for changes
  @{
 */
