@@ -339,6 +339,11 @@
     (assv-ref MonthDeltas incr))
   (define (make-interval from to)
     (list from (if (< to enddate) (decdate to SecDelta) enddate)))
+  (when (< enddate startdate)
+    (let ((saved-enddate enddate))
+      (gnc:warn "start > end date. Swapping dates to avoid some reports crashing.")
+      (set! enddate startdate)
+      (set! startdate saved-enddate)))
   (let loop ((result '())
              (date startdate)
              (idx 0))
@@ -365,6 +370,11 @@
 (define (gnc:make-date-list startdate enddate incr)
   (define month-delta
     (assv-ref MonthDeltas incr))
+  (when (< enddate startdate)
+    (let ((saved-enddate enddate))
+      (gnc:warn "start > end date. Swapping dates to avoid some reports crashing.")
+      (set! enddate startdate)
+      (set! startdate saved-enddate)))
   (let loop ((result '())
              (date startdate)
              (idx 0))
@@ -585,6 +595,7 @@ Defaulting to today."))
     (gnc-mktime now)))
 
 (define (gnc:get-start-next-year)
+  (issue-deprecation-warning "gnc:get-start-next-year is deprecated.")
   (let ((now (gnc-localtime (current-time))))
     (set-tm:sec now 0)
     (set-tm:min now 0)
@@ -596,6 +607,7 @@ Defaulting to today."))
     (gnc-mktime now)))
 
 (define (gnc:get-end-next-year)
+  (issue-deprecation-warning "gnc:get-end-next-year is deprecated.")
   (let ((now (gnc-localtime (current-time))))
     (set-tm:sec now 59)
     (set-tm:min now 59)
@@ -661,6 +673,7 @@ Defaulting to today."))
     (gnc-mktime now)))
     
 (define (gnc:get-start-next-month)
+  (issue-deprecation-warning "gnc:get-start-next-month is deprecated.")
   (let ((now (gnc-localtime (current-time))))
     (set-tm:sec now 0)
     (set-tm:min now 0)
@@ -675,6 +688,7 @@ Defaulting to today."))
     (gnc-mktime now)))
 
 (define (gnc:get-end-next-month)
+  (issue-deprecation-warning "gnc:get-end-next-month is deprecated.")
   (let ((now (gnc-localtime (current-time))))
     (set-tm:sec now 59)
     (set-tm:min now 59) 
@@ -743,6 +757,7 @@ Defaulting to today."))
     (gnc-mktime now)))
 
 (define (gnc:get-start-next-quarter)
+  (issue-deprecation-warning "gnc:get-start-next-quarter is deprecated.")
   (let ((now (gnc-localtime (current-time))))
     (set-tm:sec now 0)
     (set-tm:min now 0)
@@ -757,6 +772,7 @@ Defaulting to today."))
     (gnc-mktime now)))
 
 (define (gnc:get-end-next-quarter)
+  (issue-deprecation-warning "gnc:get-end-next-quarter is deprecated.")
   (let ((now (gnc-localtime (current-time))))
     (set-tm:sec now 59)
     (set-tm:min now 59)
@@ -776,6 +792,7 @@ Defaulting to today."))
   (current-time))
 
 (define (gnc:get-one-month-ago)
+  (issue-deprecation-warning "gnc:get-one-month-ago is deprecated.")
   (let ((now (gnc-localtime (current-time))))
     (if (= (tm:mon now) 0)
 	(begin
@@ -831,6 +848,7 @@ Defaulting to today."))
       (gnc-mktime now))))
 
 (define (gnc:get-one-month-ahead)
+  (issue-deprecation-warning "gnc:get-one-month-ahead is deprecated.")
   (let ((now (gnc-localtime (current-time))))
     (if (= (tm:mon now) 11)
 	(begin
